## Product details

Lifelike Christmas Pine Tree: The realistic Christmas tree decorated with white floss to help emulate a real Christmas tree in the snow weather. It is also accented with vivid pinecones, berries, and glimmering red balls. The 2ft mini size design is lightweight and easy to move and carry, making it an ideal decoration for garden and pathway.

Lifelike Christmas Pine Tree decorated with white floss for a snowy appearance.
Accented with vivid pinecones, berries, and glimmering red balls.
2ft mini size design is lightweight and easy to move and carry.
Equipped with 30 warm white LED lights with eight flash modes.
High-quality PVC material for lifelike and durable leaves.
Lengthened sturdy metal stand for strong support and stability.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Number of lights
30
Christmas tree feature
Pre-lit
Prelit
Y
Light bulb color
Warm
More details
## Warranty

Warranty information
90 days Warranty

Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in
